import PIL.ImageColor as Color


def getcolor(color):
    """Exactly as Pillow's getrgb function."""

    return Color.getrgb(color)


def getcolorf(color):
    """Exactly as Pillow's getrgb function, but the values are returned as floats."""

    r, g, b = Color.getrgb(color)
    return tuple([r / 255, g / 255, b / 255])



from hypothesis.strategies import floats
from hypothesis.strategies import integers

pve_num = floats(min_value=1, max_value=1e6)
real_num = floats(min_value=-1e6, max_value=1e6)

dimension = integers(min_value=4, max_value=512)
